# data for examples

Files used in examples:

  - [Doud_et_al_2018-neutdata.csv](Doud_et_al_2018-neutdata.csv>)
    is the neutralization data for FI6v3 and H17-L19 in
    [Fig 6a,b of Doud et al, 2018](https://www.nature.com/articles/s41467-018-03665-3#Fig6).

  - [rachelstyle2019_22Feb19_neutdata.xlsx](rachelstyle2019_22Feb19_neutdata.xlsx)
    is example neutralization data from Rachel Eguia.
    
  - [rachelstyle2019_22Feb19_neutdata_config.yaml](rachelstyle2019_22Feb19_neutdata_config.yaml) is a YAML file describing the configuration of the data in [rachelstyle2019_22Feb19_neutdata.xlsx](rachelstyle2019_22Feb19_neutdata.xlsx).

  - [rachelstyle2019_22Feb19_setup.pdf](rachelstyle2019_22Feb19_setup.pdf) describes exactly how the assays in [rachelstyle2019_22Feb19_neutdata.xlsx](rachelstyle2019_22Feb19_neutdata.xlsx) were set up.
